summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/main/java/org/openslx/util/vm/VboxConfig.java5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/main/java/org/openslx/util/vm/VboxConfig.java b/src/main/java/org/openslx/util/vm/VboxConfig.java
index fa7bf16..5b20650 100644
--- a/src/main/java/org/openslx/util/vm/VboxConfig.java
+++ b/src/main/java/org/openslx/util/vm/VboxConfig.java
@@ -228,7 +228,10 @@ public class VboxConfig
public void addPlaceHolders()
{
- // placeholder fot the machine uuid
+ // placeholder for the MAC address
+ changeAttribute( "Adapter", "MACAddress", "#OpenSLX_MAC_place_holder" );
+
+ // placeholder for the machine uuid
changeAttribute( "Machine", "uuid", "#OpenSLX_MUUID_place_holder" );
// placeholder for the location of the virtual hdd